##  Register SAP LeanIX in Microsoft Entra ID
  1. Based on the region, sign in to either the [Global Azure portal![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fportal.azure.com%2F "https://portal.azure.com/") or the [China Azure portal![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fportal.azure.cn%2F "https://portal.azure.cn/"). Use the Azure administrator account that is also a member of the Global Administrator directory role in your Microsoft Entra ID tenant.
  2. On the left navigation pane, click Microsoft Entra ID.


![Azure Portal](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742420c7a44101486ddbef6b2892668_LowRes.png)
Azure Portal
  1. On the Microsoft Entra ID page, click App Registrations.
  2. On the app registrations page, in the toolbar on the top, click New registration.
  3. In the resulting page, do the following:
    1. Enter a name for the integration.
    2. Under Supported account types, select Accounts in this organizational directory only (Default Directory only - Single tenant).
    3. Click Register at the bottom of the screen.
